﻿using System;
using Microsoft.SharePoint;

namespace MSDN.SPTips.Task
{
    /// <summary>
    /// SharePoint server dependent implementation of ITaskRepository
    /// </summary>
    public class SPTaskRepository : ITaskRepository
    {

        ITaskRepositoryConfig _config;

        public SPTaskRepository()
            : this(new StubbedTaskRepositoryConfig())
        {
            // in a production level application, use an IoC container
        }

        public SPTaskRepository(ITaskRepositoryConfig config)
        {
            _config = config;
        }

        public TaskCollection GetTasks()
        {

            TaskCollection tasks = new TaskCollection();

            // If you are not creating tests and just want to get a list
            // from the current Web, you can do it this way:
            // SPListItemCollection spTasks =
            // SPContext.Current.Web.Lists[_config.ListName].Items;

            // However, this doesn't work well for creating testable code. 
            // Therefore, here is an approach you can take that will work 
            // both from MSTest and when the code runs in the context of a 
            // SharePoint Web:
            // first, get the site collection
            using (SPSite site = new SPSite(_config.SiteUrl))
            {
                // then get the root web of the site collection
                using (SPWeb web = site.RootWeb)
                {
                    // finally, get the list item collection from the Web
                    SPListItemCollection spTasks = web.Lists[_config.ListName].Items;
                    foreach (SPListItem spTask in spTasks)
                    {
                        tasks.Add(new Task
                        {
                            TaskName = (string)spTask[_config.TaskNameFieldName],
                            PercentComplete = (double)spTask[_config.PercentCompleteFieldName]
                        });
                    }
                }
            }

            return tasks;
        }
    }
}
