﻿using System;

using Rhino.Mocks;
using Microsoft.VisualStudio.TestTools.UnitTesting;

using MSDN.SPTips.Task;
using MSDN.SPTips.WebPart.Presentation;

namespace SPTips.TaskService.Tests
{     
    /*
     * The tests use RhinoMocks open source framework for interaction-based testing.
     * To read more about it go to: http://ayende.com/projects/rhino-mocks.aspx 
    */

    [TestClass]        
    public class TaskPresenterTests {

        [TestMethod]
        public void InitializeView_ShouldCallToRepositoryToRetrieveTasks()
        {
            var mockTaskRepository = MockRepository.GenerateMock<ITaskRepository>();
            var mockTaskView = MockRepository.GenerateMock<IView>();

            // expect that the repository's GetTasks method is called
            var tasks = new TaskCollection();
            mockTaskRepository.Expect(x => x.GetTasks()).Return(tasks);

            // configure the Presenter with its dependencies
            var presenter = new Presenter(mockTaskView, mockTaskRepository);

            // run the object under test
            presenter.InitializeView();

            // verify that the expectations have been met
            mockTaskRepository.VerifyAllExpectations();
        }
        
        [TestMethod]
        public void InitializeView_WhenTasksRetrievedPassTasksToViewForRendering() 
        {
            var mockTaskRepository = MockRepository.GenerateMock<ITaskRepository>();
            var mockTaskView = MockRepository.GenerateMock<IView>();

            // we stub the call to repository, since we don't want to verify it again
            // it has been done in the previous test            
            var tasks = new TaskCollection();
            mockTaskRepository.Stub(x => x.GetTasks()).Return(tasks);

            // in this test we verify that the tasks are properly passed to the view from the presenter            
            mockTaskView.Expect(x => x.Tasks = tasks);

            // configure the Presenter with its dependencies
            var presenter = new Presenter(mockTaskView, mockTaskRepository);

            // run the object under test
            presenter.InitializeView();

            mockTaskView.VerifyAllExpectations();
        }   
    }
}