﻿using System;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.WebControls;
using System.Security;
using System.Web.UI;
using MSDN.SPTips.WebPart.Presentation;
using MSDN.SPTips.Task;

// The AllowPartiallyTrustedCallersAttribute requires the assembly to be signed with a strong name key.
// This attribute is necessary to allow an ASP.NET web part to be imported into SharePoint from the bin
[assembly: AllowPartiallyTrustedCallers]
namespace MSDN.SPTips.WebPart
{
    public class WebPartOffServerExample : System.Web.UI.WebControls.WebParts.WebPart, IView
    {
        private Presenter presenter;
        
        private Label _lblMessage;
        private GridView _gvTasks;

        public WebPartOffServerExample()
        {
            this.ExportMode = WebPartExportMode.All;
        }

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            // when building this web part to run on the web site
            // in this solution, use this call
            presenter = new Presenter(this, new StubbedTaskRepository());

            // when deploying this web part to SharePoint and calling
            // a SharePoint task list, use this call
            // presenter = new Presenter(this, new SPTaskRepository());
        }

        protected override void CreateChildControls()
        {
            base.CreateChildControls();
            
            _lblMessage = new Label();            
            this.Controls.Add(_lblMessage);

            _gvTasks = new GridView();

            // adjust the grid view column display
            // information and styles
            _gvTasks.AutoGenerateColumns = false;
            BoundField title = new BoundField();
            title.HeaderText = "Task Title";
            title.DataField = "TaskName";
            _gvTasks.Columns.Add(title);

            BoundField percentComplete = new BoundField();
            percentComplete.HeaderText = "% Complete";
            percentComplete.DataField = "PercentComplete";
            percentComplete.DataFormatString = "{0:p}";
            _gvTasks.Columns.Add(percentComplete);

            _gvTasks.CellPadding = 2;
            _gvTasks.Width = Unit.Percentage(100);
            _gvTasks.BackColor = System.Drawing.Color.Bisque;

            _gvTasks.Columns[1].ItemStyle.HorizontalAlign = HorizontalAlign.Center;

            this.Controls.Add(_gvTasks);
        }

        protected override void OnPreRender(EventArgs e)
        {
            base.OnPreRender(e);
            // remove the next line if you want to allow
            // the user to set the title at runtime
            this.Title = "MSDN Web Part for SP Tips article";

            _lblMessage.Text = "Solution Developed Off-Server";

            // this is where we are asking the preseter to go to the repository (model) and retrieve 
            // the data that will then be passed into the view
            presenter.InitializeView();
        }

        // override RenderContents to apply additional conditions/formatting
        // before the control(s) are rendered
        protected override void RenderContents(HtmlTextWriter writer)
        {
            EnsureChildControls();
                        
            _lblMessage.RenderControl(writer);
            _gvTasks.RenderControl(writer);
        }

        public TaskCollection Tasks
        {            
            set 
            {
                EnsureChildControls();

                _gvTasks.DataSource = value;
                _gvTasks.DataBind();
            }
        }


    }
}